aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorlangerhans <[email protected]>2014-04-14 19:07:08 +0200
committerlangerhans <[email protected]>2014-04-14 19:07:08 +0200
commit4ca4a8d5d6c73de437d8a8a576deac31515255c0 (patch)
treed6b73a8239b74d0d49e0202e05a68ef6dfbc6690 /src
parentMerge pull request #453 from rnicoll/1.7-dev-rpc-tests (diff)
downloaddiscoin-4ca4a8d5d6c73de437d8a8a576deac31515255c0.tar.xz
discoin-4ca4a8d5d6c73de437d8a8a576deac31515255c0.zip
Replace shortcut names with Dogecoin
At least on Windows this is user-facing in the Autostart folder.
Diffstat (limited to 'src')
-rw-r--r--src/qt/guiutil.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/qt/guiutil.cpp b/src/qt/guiutil.cpp
index adaa9371b..fe0a2e261 100644
--- a/src/qt/guiutil.cpp
+++ b/src/qt/guiutil.cpp
@@ -387,12 +387,12 @@ bool ToolTipToRichTextFilter::eventFilter(QObject *obj, QEvent *evt)
#ifdef WIN32
boost::filesystem::path static StartupShortcutPath()
{
- return GetSpecialFolderPath(CSIDL_STARTUP) / "Bitcoin.lnk";
+ return GetSpecialFolderPath(CSIDL_STARTUP) / "Dogecoin.lnk";
}
bool GetStartOnSystemStartup()
{
// check for Bitcoin.lnk
return boost::filesystem::exists(StartupShortcutPath());
}
@@ -469,7 +469,7 @@ boost::filesystem::path static GetAutostartDir()
boost::filesystem::path static GetAutostartFilePath()
{
- return GetAutostartDir() / "bitcoin.desktop";
+ return GetAutostartDir() / "dogecoin.desktop";
}
bool GetStartOnSystemStartup()
@@ -387,12 +387,12 @@ bool ToolTipToRichTextFilter::eventFilter(QObject *obj, QEvent *evt)
bool GetStartOnSystemStartup()
{
- // check for Bitcoin.lnk
+ // check for Dogecoin.lnk
return boost::filesystem::exists(StartupShortcutPath());
}